From 62b2b692329f8db791db08700821111238ed40be Mon Sep 17 00:00:00 2001
From: jgart <jgart@dismail.de>
Date: Sat, 17 Apr 2021 17:43:16 -0400
Subject: [PATCH] gnu: Add sc-im.

    * gnu/packages/visidata.scm: New file.
    * gnu/local.mk (GNU_SYSTEM_MODULES): Add it.

    Co-authored-by: Ekaitz Zarraga <ekaitz@elenq.tech>
---
 gnu/local.mk           |  1 +
 gnu/packages/sc-im.scm | 79 ++++++++++++++++++++++++++++++++++++++++++
 2 files changed, 80 insertions(+)
 create mode 100644 gnu/packages/sc-im.scm

diff --git a/gnu/local.mk b/gnu/local.mk
index 50b11a8ca2..ade8b400d0 100644
--- a/gnu/local.mk
+++ b/gnu/local.mk
@@ -496,6 +496,7 @@ GNU_SYSTEM_MODULES =				\
   %D%/packages/sawfish.scm			\
   %D%/packages/scanner.scm			\
   %D%/packages/scheme.scm			\
+  %D%/packages/sc-im.scm			\
   %D%/packages/screen.scm			\
   %D%/packages/scribus.scm			\
   %D%/packages/scsi.scm				\
diff --git a/gnu/packages/sc-im.scm b/gnu/packages/sc-im.scm
new file mode 100644
index 0000000000..082d40d51c
--- /dev/null
+++ b/gnu/packages/sc-im.scm
@@ -0,0 +1,79 @@
+;;; GNU Guix --- Functional package management for GNU
+;;; Copyright © 2020 Ekaitz Zarraga <ekaitz@elenq.tech>
+;;; Copyright © 2021 jgart <jgart@dismail.de>
+;;;
+;;; This file is part of GNU Guix.
+;;;
+;;; GNU Guix is free software; you can redistribute it and/or modify it
+;;; under the terms of the GNU General Public License as published by
+;;; the Free Software Foundation; either version 3 of the License, or (at
+;;; your option) any later version.
+;;;
+;;; GNU Guix is distributed in the hope that it will be useful, but
+;;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;;; GNU General Public License for more details.
+;;;
+;;; You should have received a copy of the GNU General Public License
+;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.
+
+(define-module (gnu packages sc-im)
+  #:use-module (guix packages)
+  #:use-module (guix git-download)
+  #:use-module (guix download)
+  #:use-module (guix build-system gnu)
+  #:use-module ((guix licenses) #:prefix license:)
+  #:use-module (gnu packages)
+  #:use-module (gnu packages base)
+  #:use-module (gnu packages pkg-config)
+  #:use-module (gnu packages maths)
+  #:use-module (gnu packages statistics)
+  #:use-module (gnu packages xml)
+  #:use-module (gnu packages compression)
+  #:use-module (gnu packages bison)
+  #:use-module (gnu packages ncurses))
+
+(define-public sc-im
+  (let ((commit-ref "75ae3806844821cba1b2e3fdb9237d737944e850"))
+    (package
+      (name "sc-im")
+      (version "0.8.1")
+      (source (origin
+                (method git-fetch)
+                (uri
+                  (git-reference
+                    (url "https://github.com/andmarti1424/sc-im.git")
+                    (commit commit-ref)))
+                (sha256
+                  (base32
+                    "1i1yq5mh9d7yi1bkgaq4p1lr8zrxhlvqmjnj33wmg5v6vpfim1h0"))))
+      (build-system gnu-build-system)
+      (arguments
+        ;; There are no tests at the moment.
+        ;; https://github.com/andmarti1424/sc-im/issues/537
+        ;; https://github.com/andmarti1424/sc-im/pull/385
+        `(#:tests? #f
+          #:make-flags (list "-C" "src" "CC=gcc"
+                         (string-append "prefix=" (assoc-ref %outputs "out")))
+          #:phases
+            (modify-phases
+               %standard-phases
+                 (delete 'configure))))
+      (inputs
+        `(("gnuplot" ,gnuplot)
+          ("libxls" ,libxls)
+          ("libxlsxwriter" ,libxlsxwriter)
+          ("libxml2" ,libxml2)
+          ("libzip" ,libzip)
+          ("ncurses" ,ncurses)))
+      (native-inputs
+        `(("pkg-config" ,pkg-config)
+          ("which" ,which)
+          ("bison" ,bison)))
+      (synopsis "Spreadsheet program with vim-like keybindings")
+      (description
+ "@code{sc-im} is a highly configurable spreadsheet program
+ providing a vim-like experience.  @code{sc-im} supports @{gnuplot} interaction,
+ functions for sorting and filtering, 256 color support, and much more.")
+      (home-page "https://github.com/andmarti1424/sc-im")
+      (license license:bsd-4))))
-- 
2.29.3

